***********************************************************************************
*** This do file creates the database for 
*** Country or Leader? Political Change and UN General Assembly Voting
*** Axel Dreher (Heidelberg University, Georg-August University Gttingen, KOF, CESifo, IZA)
*** Nathan Jensen (Washington University in St. Louis)
*****************************************************************************************
*** Last update: November 25, 2012 AD
*****************************************************************************************


drop _all
clear matrix
version 11.0
set mem 2000m
set mat 2000


***********************************************************************************
local DIR = "D:\Eigene Dateien\Papers\Nate\Stata\"  /*change relative path to the directory where the files are located */
cd "`DIR'"
***********************************************************************************



** checks whether folder "bearbeitet" (where transformed data are stored) and "tables" (where tables are stored) exist and creates it if not
program define confirmdir, rclass
 	local cwd `"`c(pwd)'"'
	quietly capture cd `"`1'"'
	local confirmdir=_rc 
	quietly cd `"`cwd'"'
	return local confirmdir `"`confirmdir'"'
end 
	confirmdir `"bearbeitet"'	  /* does folder "bearbeitet" exist? */
		if `r(confirmdir)'!=0  {  /* folder does not yet exist */
			mkdir "bearbeitet"  /* makes the folder  */
					      } 
	      else {
			di "folder bearbeitet already exists"
			}
	confirmdir `"tables"'		  /* does folder "tables" exist? */
		if `r(confirmdir)'!=0  {  /* folder does not yet exist */
			mkdir "tables"  /* makes the folder  */
					      } 
	      else {
			di "folder tables already exists"
			}
program drop confirmdir

log using "tables\Dreher, Jensen.log", replace


**** generate id
use "bearbeitet\Dreher Jensen EJPE replication", clear



*************************************************************************************************************************
**************************************************** Regressions and Graphs ********************************************************
*************************************************************************************************************************
/* Graph for World Averages */
label var inlineusk_mean "key votes (average)"
label var inlineusnk_mean "non-key votes (average)"
twoway (tsline inlineusk_mean if code=="ABW", lpattern(dash)) (tsline inlineusnk_mean if code=="ABW") if year>1982, ytitle(Voting Coincidence with the U.S.) ttitle(Year) xscale(range (1983 2008)) xlab(1983 1990 1995 2000 2005)

/* Bulgaria */
label var inlineusk_mean "average"
label var inlinekey_usa "Bulgaria"
twoway (tsline inlineusk_mean if code=="BGR", lpattern(dash)) (tsline inlinekey_usa if code=="BGR") if year>1982, ytitle("") title(key votes) xscale(range (1983 2008)) xlab(1983 1990 1995 2000 2005)
graph save tables\bulg_key, replace
label var inlineusnk_mean "average"
label var inlinenokey_usa "Bulgaria"
twoway (tsline inlineusnk_mean if code=="BGR", lpattern(dash)) (tsline inlinenokey_usa if code=="BGR") if year>1982, ytitle("") title(non-key votes) xscale(range (1983 2008)) xlab(1983 1990 1995 2000 2005)
graph save tables\bulg_nkey, replace

graph combine tables\bulg_key.gph tables\bulg_nkey.gph, b2title(year) l2title(Voting Coincidence with the U.S.) xsize(7)
erase tables\bulg_key.gph tables\bulg_nkey.gph


/* France */
label var inlineusk_mean "average"
label var inlinekey_usa "France"
twoway (tsline inlineusk_mean if code=="FRA", lpattern(dash)) (tsline inlinekey_usa if code=="FRA") if year>1982, ytitle("") title(key votes) xscale(range (1983 2008)) xlab(1983 1990 1995 2000 2005)
graph save tables\bulg_key, replace
label var inlineusnk_mean "average"
label var inlinenokey_usa "France"
twoway (tsline inlineusnk_mean if code=="FRA", lpattern(dash)) (tsline inlinenokey_usa if code=="FRA") if year>1982, ytitle("") title(non-key votes) xscale(range (1983 2008)) xlab(1983 1990 1995 2000 2005)
graph save tables\bulg_nkey, replace

graph combine tables\bulg_key.gph tables\bulg_nkey.gph, b2title(year) l2title(Voting Coincidence with the U.S.) xsize(7)
erase tables\bulg_key.gph tables\bulg_nkey.gph

/* Egypt */
label var inlineusk_mean "average"
label var inlinekey_usa "Egypt"
twoway (tsline inlineusk_mean if code=="EGY", lpattern(dash)) (tsline inlinekey_usa if code=="EGY") if year>1982, ytitle("") title(key votes) xscale(range (1983 2008)) xlab(1983 1990 1995 2000 2005)
graph save tables\bulg_key, replace
label var inlineusnk_mean "average"
label var inlinenokey_usa "Egypt"
twoway (tsline inlineusnk_mean if code=="EGY", lpattern(dash)) (tsline inlinenokey_usa if code=="EGY") if year>1982, ytitle("") title(non-key votes) xscale(range (1983 2008)) xlab(1983 1990 1995 2000 2005)
graph save tables\bulg_nkey, replace

graph combine tables\bulg_key.gph tables\bulg_nkey.gph, b2title(year) l2title(Voting Coincidence with the U.S.) xsize(7)
erase tables\bulg_key.gph tables\bulg_nkey.gph



/* Table 1: key votes */
xtreg inlinekey_usa colour_l prs_l lgdp_pc_l gg_l imports_gdp_l odacomUSA_gdp_l, fe cluster(id)
estimates store c1
xtreg inlinekey_usa colour_l prs_l lgdp_pc_l gg_l imports_gdp_l odacomUSA_gdp_l change_leader, fe cluster(id)
estimates store c2
xtabond2 inlinekey_usa colour_l prs_l lgdp_pc_l gg_l imports_gdp_l odacomUSA_gdp_l change_leader time*	///
		 , gmm(imports_gdp_l odacomUSA_gdp_l, c) ivstyle(change_leader prs_l lgdp_pc_l gg_l) small two robust
estimates store c3
reg inlinekey_usa colour_l prs_l lgdp_pc_l gg_l imports_gdp_l odacomUSA_gdp_l change_leader, cluster(id)
estimates store c4
xtreg inlinekey_usa colour_l prs_l lgdp_pc_l change_leader, fe cluster(id)
estimates store c5
xtreg inlinekey_usa colour_l prs_l lgdp_pc_l change_leader cold leader_cold, fe cluster(id)  
testparm change_leader leader_cold
estimates store c6


estout c1 c2 c3 c4 c5 c6 using "tables\table 1.txt", replace label delimiter(_tab) noabbrev  							///
				cells(b(star fmt(%9.3f)) t(par abs fmt(2))) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) 		///
				drop(_cons time*)																					///
				stats(N N_g j ar2p hansenp,	labels("Number of observations" "Number of countries" 					///
				"Number of instruments" "Arellano-Bond test (Pr>z)" "Hansen test (Prob>chi2)") fmt(0 0 0 2 2)) 		///
				order(change_leader cold leader_cold colour_l prs_l lgdp_pc_l gg_l imports_gdp_l odacomUSA_gdp_l)	///
				mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)")
				
				
/* Table 2: additional tests, key votes only*/
*** includes world Average
xtabond2 inlinekey_usa colour_l prs_l lgdp_pc_l gg_l imports_gdp_l odacomUSA_gdp_l change_leader inlineusk_mean time*	///
		 , gmm(imports_gdp_l odacomUSA_gdp_l inlineusk_mean, c) ivstyle(change_leader colour_l prs_l lgdp_pc_l gg_l) small two robust
estimates store c1
*** includes Non-key votes
xtabond2 inlinekey_usa colour_l prs_l lgdp_pc_l gg_l imports_gdp_l odacomUSA_gdp_l change_leader inlinenokey_usa time*	///
		 , gmm(imports_gdp_l odacomUSA_gdp_l inlinenokey_usa, c) ivstyle(change_leader colour_l prs_l lgdp_pc_l gg_l) small two robust
estimates store c2
*** includes left governments coming to power 
xtabond2 inlinekey_usa colour_l prs_l lgdp_pc_l gg_l imports_gdp_l odacomUSA_gdp_l change_leader left_c time*	///
		 , gmm(imports_gdp_l odacomUSA_gdp_l left_c, c) ivstyle(change_leader colour_l prs_l lgdp_pc_l gg_l) small two robust
estimates store c3
*** includes changes in Polity Score 
xtabond2 inlinekey_usa colour_l prs_l lgdp_pc_l gg_l imports_gdp_l odacomUSA_gdp_l change_leader polity2_c time*	///
		 , gmm(imports_gdp_l odacomUSA_gdp_l polity2_c, c) ivstyle(change_leader colour_l prs_l lgdp_pc_l gg_l) small two robust
estimates store c4
*** years in office rather change
xtabond2 inlinekey_usa colour_l prs_l lgdp_pc_l gg_l imports_gdp_l odacomUSA_gdp_l yrsoff time*	///
		 , gmm(imports_gdp_l odacomUSA_gdp_l, c) ivstyle(yrsoff colour_l prs_l lgdp_pc_l gg_l) small two robust
estimates store c5

estout c1 c2 c3 c4 c5 using "tables\table 2.txt", replace label delimiter(_tab) noabbrev  							///
				cells(b(star fmt(%9.3f)) t(par abs fmt(2))) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) 		///
				drop(_cons time*)																					///
				stats(N N_g j ar2p hansenp,	labels("Number of observations" "Number of countries" 					///
				"Number of instruments" "Arellano-Bond test (Pr>z)" "Hansen test (Prob>chi2)") fmt(0 0 0 2 2)) 		///
				order(change_leader colour_l prs_l lgdp_pc_l gg_l imports_gdp_l odacomUSA_gdp_l						///
				inlineusk_mean inlinenokey_usa left_c polity2_c yrsoff)												///
				mlabels("(1)" "(2)" "(3)" "(4)" "(5)")
				
				
				
/* Table 3: non key votes */
xtreg inlinenokey_usa colour_l prs_l lgdp_pc_l gg_l imports_gdp_l odacomUSA_gdp_l, fe cluster(id)
estimates store c1
xtreg inlinenokey_usa colour_l prs_l lgdp_pc_l gg_l imports_gdp_l odacomUSA_gdp_l change_leader, fe cluster(id)
estimates store c2
xtabond2 inlinenokey_usa colour_l prs_l lgdp_pc_l gg_l imports_gdp_l odacomUSA_gdp_l change_leader time*	///
		 , gmm(l.imports_gdp l.odacomUSA_gdp, c) ivstyle(change_leader l.prs l.lgdp_pc l.gg ) small two robust
estimates store c3
reg inlinenokey_usa colour_l prs_l lgdp_pc_l gg_l imports_gdp_l odacomUSA_gdp_l change_leader, cluster(id)
estimates store c4
xtreg inlinenokey_usa colour_l prs_l lgdp_pc_l change_leader, fe cluster(id)
estimates store c5
xtreg inlinenokey_usa colour_l prs_l lgdp_pc_l change_leader cold leader_cold, fe cluster(id)  
estimates store c6
testparm change_leader leader_cold
xtreg inlinenokey_usa colour_l prs_l lgdp_pc_l change_leader if cold==1, fe cluster(id) /* Cold War only */ 

estout c1 c2 c3 c4 c5 c6 using "tables\table 3.txt", replace label delimiter(_tab) noabbrev  							///
				cells(b(star fmt(%9.3f)) t(par abs fmt(2))) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) 		///
				drop(_cons time*)																					///
				stats(N N_g j ar2p hansenp,	labels("Number of observations" "Number of countries" 					///
				"Number of instruments" "Arellano-Bond test (Pr>z)" "Hansen test (Prob>chi2)") fmt(0 0 0 2 2)) 		///
				order(change_leader cold leader_cold colour_l prs_l lgdp_pc_l gg_l imports_gdp_l odacomUSA_gdp_l)	///
				mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)")

								
			
/* Table 4: Table Leader Death: key votes */
xtreg inlinekey_usa colour_l prs_l lgdp_pc_l gg_l imports_gdp_l odacomUSA_gdp_l death, fe cluster(id)
estimates store c1
xtabond2 inlinekey_usa colour_l prs_l lgdp_pc_l gg_l imports_gdp_l odacomUSA_gdp_l death time*	///
		 , gmm(imports_gdp_l odacomUSA_gdp_l, c) ivstyle(death colour_l prs_l lgdp_pc_l gg_l) small two robust
estimates store c2
xtreg inlinekey_usa colour_l prs_l lgdp_pc_l death, fe cluster(id)
estimates store c3

estout c1 c2 c3 using "tables\table 4.txt", replace label delimiter(_tab) noabbrev  								///
				cells(b(star fmt(%9.3f)) t(par abs fmt(2))) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) 		///
				drop(_cons time*)																					///
				stats(N N_g j ar2p hansenp,	labels("Number of observations" "Number of countries" 					///
				"Number of instruments" "Arellano-Bond test (Pr>z)" "Hansen test (Prob>chi2)") fmt(0 0 0 2 2)) 		///
				order(death colour_l prs_l lgdp_pc_l gg_l imports_gdp_l odacomUSA_gdp_l)	 				///
				mlabels("(1)" "(2)" "(3)")



/* Descriptive statistics, Table 1, column 2 */
xtreg inlinekey_usa l.colour l.prs l.lgdp_pc gg l.imports_gdp l.odacomUSA_gdp, fe cluster(id)
su inlinekey_usa inlinenokey_usa change_leader death yrsoff colour_l prs_l lgdp_pc_l gg_l imports_gdp_l odacomUSA_gdp_l inlineusk_mean left_c polity2_c if e(sample), sep(200)



